@@ -5,12 +5,14 @@
 #include <QNetworkAccessManager>
 #include <QDebug>
 #include <QFileDialog>
+#include <QPointer>
 #ifdef Q_WS_MAEMO_5
     #include <QMaemo5InformationBox>
 #endif
 #include <QMessageBox>
 #include "widgets/photoitem.h"
 #include "imageuploaddialog.h"
+#include "progressdialog.h"
 #include "qfacebook.h"
 
 // Starts from 0, this means 4 columns
@@ -38,10 +40,12 @@ private:
     QString accessToken;
     QString albumId;
     QNetworkAccessManager *nam;
+    QNetworkReply *uploadReply;
     QString albumCount;
     QList<PhotoItem*> photos;
     QStringList sourceLinks;
-    QDialog *progressDialog;
+    QPointer<ProgressDialog> progressDialog;
+    QMap<QNetworkReply*,QString> replyMap;
     int column;
     int row;
     int m_imagesCount;
@@ -55,6 +59,9 @@ private slots:
     void onPhotoItemClicked(PhotoItem*);
     void onDownloadFinished();
     void downloadAllPhotos();
+    void uploadPhotos(QStringList);
+    void onUploadFinished();
+    void uploadProgressChanged(qint64,qint64);
 };
 
 #endif // ALBUMWINDOW_H
