@@ -29,7 +29,7 @@ void GroupsWindow::browseGroups(QString userId)
 
 void GroupsWindow::onGroupClicked(QListWidgetItem *item)
 {
-    ProfileWindow *group = new ProfileWindow(this, accessToken);
+    ProfileWindow *group = new ProfileWindow(this, accessToken, ProfileWindow::GroupProfile);
     group->setWindowTitle(item->text());
     group->browseProfile(item->data(Qt::UserRole).toString());
 #ifdef Q_WS_S60
