@@ -8,6 +8,7 @@
     #include <QMessageBox>
 #endif
 #include <QDebug>
+#include <QDesktopWidget>
 #include <qfacebook.h>
 
 namespace Ui {
@@ -34,7 +35,7 @@ private:
 private slots:
     void accept();
     void onReplyReceived();
-
+    void orientationChanged();
 };
 
 #endif // NEWEVENTDIALOG_H
