@@ -38,10 +38,12 @@ private:
     QString m_subjectText;
     QString m_toWallId;
     bool isCreateMode;
+    bool isEditMode;
 
 private slots:
     void onReplyReceived();
     void onNotePosted();
+    void onEditTriggered();
 };
 
 #endif // NOTEWINDOW_H
